@@ -1,8 +1,10 @@
 #include "fastfetch.h"
 #include "detection/media/media.h"
 #include "common/library.h"
+#include "common/processing.h"
 #include "util/apple/cf_helpers.h"
 #include "util/apple/osascript.h"
+#include "fastfetch_datatext.h"
 
 #import <Foundation/Foundation.h>
 #import <CoreFoundation/CoreFoundation.h>
@@ -13,7 +15,7 @@ extern CFStringRef MRNowPlayingClientGetBundleIdentifier(id clientObj) __attribu
 extern CFStringRef MRNowPlayingClientGetParentAppBundleIdentifier(id clientObj) __attribute__((weak_import));
 void MRMediaRemoteGetNowPlayingApplicationIsPlaying(dispatch_queue_t queue, void (^callback)(BOOL playing)) __attribute__((weak_import));
 
-static const char* getMedia(FFMediaResult* result)
+static const char* getMediaByMediaRemote(FFMediaResult* result)
 {
     #define FF_TEST_FN_EXISTANCE(fn) if (!fn) return "MediaRemote function " #fn " is not available"
     FF_TEST_FN_EXISTANCE(MRMediaRemoteGetNowPlayingInfo);
@@ -79,8 +81,34 @@ static const char* getMedia(FFMediaResult* result)
     return error;
 }
 
+static const char* getMediaByOsascript(FFMediaResult* result)
+{
+    FF_STRBUF_AUTO_DESTROY buffer = ffStrbufCreate();
+    // The script must be executed by `/usr/bin/osascript`. `ffOsascript` doesn't work here
+    const char* error = ffProcessAppendStdOut(&buffer, (char* const[]) {
+        "/usr/bin/osascript",
+        "-e",
+        FASTFETCH_DATATEXT_NOWPLAYING,
+        nil
+    });
+    if (error) return error;
+    if (buffer.length == 0) return "No media found";
+
+    // status\ntitle\nartist\nalbum\nbundleName\nappName
+    FFstrbuf* const varList[] = { &result->status, &result->song, &result->artist, &result->album, &result->playerId, &result->player };
+    char* line = NULL;
+    size_t len = 0;
+    for (uint32_t i = 0; i < ARRAY_SIZE(varList) && ffStrbufGetline(&line, &len, &buffer); ++i)
+        ffStrbufSetS(varList[i], line);
+    return NULL;
+}
+
 void ffDetectMediaImpl(FFMediaResult* media)
 {
-    const char* error = getMedia(media);
-    ffStrbufAppendS(&media->error, error);
+    const char* error;
+    if (@available(macOS 15.4, *))
+        error = getMediaByOsascript(media);
+    else
+        error = getMediaByMediaRemote(media);
+    if (error) ffStrbufAppendS(&media->error, error);
 }
