@@ -1,4 +1,5 @@
 #include "swap.h"
+#include "util/FFlist.h"
 #include "util/mallocHelper.h"
 
 #include <sys/types.h>
@@ -6,13 +7,13 @@
 #include <sys/param.h>
 #include <unistd.h>
 
-const char* ffDetectSwap(FFSwapResult* swap)
+const char* ffDetectSwap(FFlist* result)
 {
     int nswap = swapctl(SWAP_NSWAP, 0, 0);
     if (nswap < 0) return "swapctl(SWAP_NSWAP) failed";
-    if (nswap == 0) NULL;
+    if (nswap == 0) return NULL;
 
-    struct swapent* swdev = malloc((uint32_t) nswap * sizeof(*swdev));
+    FF_AUTO_FREE struct swapent* swdev = malloc((uint32_t) nswap * sizeof(*swdev));
 
     if (swapctl(SWAP_STATS, swdev, nswap) < 0)
         return "swapctl(SWAP_STATS) failed";
@@ -21,8 +22,10 @@ const char* ffDetectSwap(FFSwapResult* swap)
     {
         if (swdev[i].se_flags & SWF_ENABLE)
         {
-            swap->bytesUsed += (uint64_t) swdev[i].se_inuse * DEV_BSIZE;
-            swap->bytesTotal += (uint64_t) swdev[i].se_nblks * DEV_BSIZE;
+            FFSwapResult* swap = ffListAdd(result);
+            ffStrbufInitS(&swap->name, swdev[i].se_path);
+            swap->bytesUsed = (uint64_t) swdev[i].se_inuse * DEV_BSIZE;
+            swap->bytesTotal = (uint64_t) swdev[i].se_nblks * DEV_BSIZE;
         }
     }
 
