@@ -1,9 +1,11 @@
 #include "fastfetch.h"
 #include "common/commandoption.h"
+#include "common/init.h"
 #include "common/io/io.h"
 #include "common/jsonconfig.h"
 #include "common/printing.h"
 #include "detection/version/version.h"
+#include "logo/logo.h"
 #include "util/stringUtils.h"
 #include "util/mallocHelper.h"
 #include "fastfetch_datatext.h"
