@@ -20,6 +20,8 @@ static void printGPUResult(FFGPUOptions* options, uint8_t index, const FFGPUResu
         default: type = "Unknown"; break;
     }
 
+    FFPercentageTypeFlags percentType = options->percent.type == 0 ? instance.config.display.percentType : options->percent.type;
+
     if(options->moduleArgs.outputFormat.length == 0)
     {
         ffPrintLogoAndKey(FF_GPU_MODULE_NAME, index, &options->moduleArgs, FF_PRINT_TYPE_DEFAULT);
@@ -53,16 +55,28 @@ static void printGPUResult(FFGPUOptions* options, uint8_t index, const FFGPUResu
         {
             ffStrbufAppendS(&output, " (");
 
-            if(gpu->dedicated.used != FF_GPU_VMEM_SIZE_UNSET)
+            if (!(percentType & FF_PERCENTAGE_TYPE_HIDE_OTHERS_BIT))
             {
-                ffParseSize(gpu->dedicated.used, &output);
-                ffStrbufAppendS(&output, " / ");
+                if(gpu->dedicated.used != FF_GPU_VMEM_SIZE_UNSET)
+                {
+                    ffParseSize(gpu->dedicated.used, &output);
+                    ffStrbufAppendS(&output, " / ");
+                }
+                ffParseSize(gpu->dedicated.total, &output);
             }
-            ffParseSize(gpu->dedicated.total, &output);
             if(gpu->dedicated.used != FF_GPU_VMEM_SIZE_UNSET)
             {
-                ffStrbufAppendS(&output, ", ");
-                ffPercentAppendNum(&output, (double) gpu->dedicated.used / (double) gpu->dedicated.total * 100.0, options->percent, false, &options->moduleArgs);
+                double percent = (double) gpu->dedicated.used / (double) gpu->dedicated.total * 100.0;
+                if (percentType & FF_PERCENTAGE_TYPE_NUM_BIT)
+                {
+                    ffStrbufAppendS(&output, ", ");
+                    ffPercentAppendNum(&output, percent, options->percent, false, &options->moduleArgs);
+                }
+                if (percentType & FF_PERCENTAGE_TYPE_BAR_BIT)
+                {
+                    ffStrbufAppendS(&output, " ");
+                    ffPercentAppendBar(&output, percent, options->percent, &options->moduleArgs);
+                }
             }
             ffStrbufAppendC(&output, ')');
         }
@@ -78,16 +92,47 @@ static void printGPUResult(FFGPUOptions* options, uint8_t index, const FFGPUResu
         ffTempsAppendNum(gpu->temperature, &tempStr, options->tempConfig, &options->moduleArgs);
         FF_STRBUF_AUTO_DESTROY dTotal = ffStrbufCreate();
         FF_STRBUF_AUTO_DESTROY dUsed = ffStrbufCreate();
-        FF_STRBUF_AUTO_DESTROY sTotal = ffStrbufCreate();
-        FF_STRBUF_AUTO_DESTROY sUsed = ffStrbufCreate();
+        FF_STRBUF_AUTO_DESTROY dPercentNum = ffStrbufCreate();
+        FF_STRBUF_AUTO_DESTROY dPercentBar = ffStrbufCreate();
         if (gpu->dedicated.total != FF_GPU_VMEM_SIZE_UNSET) ffParseSize(gpu->dedicated.total, &dTotal);
         if (gpu->dedicated.used != FF_GPU_VMEM_SIZE_UNSET) ffParseSize(gpu->dedicated.used, &dUsed);
+        if (gpu->dedicated.total != FF_GPU_VMEM_SIZE_UNSET && gpu->dedicated.used != FF_GPU_VMEM_SIZE_UNSET)
+        {
+            double percent = (double) gpu->dedicated.used / (double) gpu->dedicated.total * 100.0;
+            if (percentType & FF_PERCENTAGE_TYPE_NUM_BIT)
+                ffPercentAppendNum(&dPercentNum, percent, options->percent, false, &options->moduleArgs);
+            if (percentType & FF_PERCENTAGE_TYPE_BAR_BIT)
+                ffPercentAppendBar(&dPercentBar, percent, options->percent, &options->moduleArgs);
+        }
+
+        FF_STRBUF_AUTO_DESTROY sTotal = ffStrbufCreate();
+        FF_STRBUF_AUTO_DESTROY sUsed = ffStrbufCreate();
+        FF_STRBUF_AUTO_DESTROY sPercentNum = ffStrbufCreate();
+        FF_STRBUF_AUTO_DESTROY sPercentBar = ffStrbufCreate();
         if (gpu->shared.total != FF_GPU_VMEM_SIZE_UNSET) ffParseSize(gpu->shared.total, &sTotal);
         if (gpu->shared.used != FF_GPU_VMEM_SIZE_UNSET) ffParseSize(gpu->shared.used, &sUsed);
+        if (gpu->shared.total != FF_GPU_VMEM_SIZE_UNSET && gpu->shared.used != FF_GPU_VMEM_SIZE_UNSET)
+        {
+            double percent = (double) gpu->shared.used / (double) gpu->shared.total * 100.0;
+            if (percentType & FF_PERCENTAGE_TYPE_NUM_BIT)
+                ffPercentAppendNum(&sPercentNum, percent, options->percent, false, &options->moduleArgs);
+            if (percentType & FF_PERCENTAGE_TYPE_BAR_BIT)
+                ffPercentAppendBar(&sPercentBar, percent, options->percent, &options->moduleArgs);
+        }
 
         FF_STRBUF_AUTO_DESTROY frequency = ffStrbufCreate();
         ffParseFrequency(gpu->frequency, &frequency);
 
+        FF_STRBUF_AUTO_DESTROY coreUsageNum = ffStrbufCreate();
+        FF_STRBUF_AUTO_DESTROY coreUsageBar = ffStrbufCreate();
+        if (gpu->coreUsage == gpu->coreUsage) //FF_GPU_CORE_USAGE_UNSET
+        {
+            if (percentType & FF_PERCENTAGE_TYPE_NUM_BIT)
+                ffPercentAppendNum(&coreUsageNum, gpu->coreUsage, options->percent, false, &options->moduleArgs);
+            if (percentType & FF_PERCENTAGE_TYPE_BAR_BIT)
+                ffPercentAppendBar(&coreUsageBar, gpu->coreUsage, options->percent, &options->moduleArgs);
+        }
+
         FF_PRINT_FORMAT_CHECKED(FF_GPU_MODULE_NAME, index, &options->moduleArgs, FF_PRINT_TYPE_DEFAULT, ((FFformatarg[]) {
             FF_FORMAT_ARG(gpu->vendor, "vendor"),
             FF_FORMAT_ARG(gpu->name, "name"),
@@ -102,6 +147,13 @@ static void printGPUResult(FFGPUOptions* options, uint8_t index, const FFGPUResu
             FF_FORMAT_ARG(gpu->platformApi, "platform-api"),
             FF_FORMAT_ARG(frequency, "frequency"),
             FF_FORMAT_ARG(index, "index"),
+            FF_FORMAT_ARG(dPercentNum, "dedicated-percentage-num"),
+            FF_FORMAT_ARG(dPercentBar, "dedicated-percentage-bar"),
+            FF_FORMAT_ARG(sPercentNum, "shared-percentage-num"),
+            FF_FORMAT_ARG(sPercentBar, "shared-percentage-bar"),
+            FF_FORMAT_ARG(coreUsageNum, "core-usage-num"),
+            FF_FORMAT_ARG(coreUsageBar, "core-usage-bar"),
+            FF_FORMAT_ARG(gpu->memoryType, "memory-type"),
         }));
     }
 }
@@ -121,6 +173,9 @@ void ffPrintGPU(FFGPUOptions* options)
 
     FF_LIST_FOR_EACH(FFGPUResult, gpu, gpus)
     {
+        if(gpu->type == FF_GPU_TYPE_UNKNOWN && options->hideType == FF_GPU_TYPE_UNKNOWN)
+            continue;
+
         if(gpu->type == FF_GPU_TYPE_INTEGRATED && options->hideType == FF_GPU_TYPE_INTEGRATED)
             continue;
 
@@ -142,6 +197,7 @@ void ffPrintGPU(FFGPUOptions* options)
         ffStrbufDestroy(&gpu->name);
         ffStrbufDestroy(&gpu->driver);
         ffStrbufDestroy(&gpu->platformApi);
+        ffStrbufDestroy(&gpu->memoryType);
     }
 }
 
@@ -177,7 +233,8 @@ bool ffParseGPUCommandOptions(FFGPUOptions* options, const char* key, const char
     if (ffStrEqualsIgnCase(subKey, "hide-type"))
     {
         options->hideType = (FFGPUType) ffOptionParseEnum(key, value, (FFKeyValuePair[]) {
-            { "none", FF_GPU_TYPE_UNKNOWN },
+            { "none", FF_GPU_TYPE_NONE },
+            { "unknown", FF_GPU_TYPE_UNKNOWN },
             { "integrated", FF_GPU_TYPE_INTEGRATED },
             { "discrete", FF_GPU_TYPE_DISCRETE },
             {},
@@ -235,7 +292,8 @@ void ffParseGPUJsonObject(FFGPUOptions* options, yyjson_val* module)
         {
             int value;
             const char* error = ffJsonConfigParseEnum(val, &value, (FFKeyValuePair[]) {
-                { "none", FF_GPU_TYPE_UNKNOWN },
+                { "none", FF_GPU_TYPE_NONE },
+                { "unknown", FF_GPU_TYPE_UNKNOWN },
                 { "integrated", FF_GPU_TYPE_INTEGRATED },
                 { "discrete", FF_GPU_TYPE_DISCRETE },
                 {},
@@ -292,9 +350,12 @@ void ffGenerateGPUJsonConfig(FFGPUOptions* options, yyjson_mut_doc* doc, yyjson_
     {
         switch (options->hideType)
         {
-            case FF_GPU_TYPE_UNKNOWN:
+            case FF_GPU_TYPE_NONE:
                 yyjson_mut_obj_add_str(doc, module, "hideType", "none");
                 break;
+            case FF_GPU_TYPE_UNKNOWN:
+                yyjson_mut_obj_add_str(doc, module, "hideType", "unknown");
+                break;
             case FF_GPU_TYPE_INTEGRATED:
                 yyjson_mut_obj_add_str(doc, module, "hideType", "integrated");
                 break;
@@ -347,9 +408,6 @@ void ffGenerateGPUJsonResult(FFGPUOptions* options, yyjson_mut_doc* doc, yyjson_
         else
             yyjson_mut_obj_add_null(doc, dedicatedObj, "used");
 
-        yyjson_mut_obj_add_strbuf(doc, obj, "driver", &gpu->driver);
-        yyjson_mut_obj_add_strbuf(doc, obj, "name", &gpu->name);
-
         yyjson_mut_val* sharedObj = yyjson_mut_obj_add_obj(doc, memoryObj, "shared");
         if (gpu->shared.total != FF_GPU_VMEM_SIZE_UNSET)
             yyjson_mut_obj_add_uint(doc, sharedObj, "total", gpu->shared.total);
@@ -360,6 +418,14 @@ void ffGenerateGPUJsonResult(FFGPUOptions* options, yyjson_mut_doc* doc, yyjson_
         else
             yyjson_mut_obj_add_null(doc, sharedObj, "used");
 
+        if (gpu->memoryType.length)
+            yyjson_mut_obj_add_strbuf(doc, memoryObj, "type", &gpu->memoryType);
+        else
+            yyjson_mut_obj_add_null(doc, memoryObj, "type");
+
+        yyjson_mut_obj_add_strbuf(doc, obj, "driver", &gpu->driver);
+        yyjson_mut_obj_add_strbuf(doc, obj, "name", &gpu->name);
+
         if(gpu->temperature == gpu->temperature) //FF_GPU_TEMP_UNSET
             yyjson_mut_obj_add_real(doc, obj, "temperature", gpu->temperature);
         else
@@ -389,6 +455,7 @@ void ffGenerateGPUJsonResult(FFGPUOptions* options, yyjson_mut_doc* doc, yyjson_
         ffStrbufDestroy(&gpu->name);
         ffStrbufDestroy(&gpu->driver);
         ffStrbufDestroy(&gpu->platformApi);
+        ffStrbufDestroy(&gpu->memoryType);
     }
 }
 
@@ -414,6 +481,13 @@ static FFModuleBaseInfo ffModuleInfo = {
         {"The platform API used when detecting the GPU", "platform-api"},
         {"Current frequency in GHz", "frequency"},
         {"GPU vendor specific index", "index"},
+        {"Dedicated memory usage percentage num", "dedicated-percentage-num"},
+        {"Dedicated memory usage percentage bar", "dedicated-percentage-bar"},
+        {"Shared memory usage percentage num", "shared-percentage-num"},
+        {"Shared memory usage percentage bar", "shared-percentage-bar"},
+        {"Core usage percentage num", "core-usage-num"},
+        {"Core usage percentage bar", "core-usage-bar"},
+        {"Memory type (Windows only)", "memory-type"},
     })),
 };
 
@@ -431,7 +505,7 @@ void ffInitGPUOptions(FFGPUOptions* options)
         #endif
     ;
     options->temp = false;
-    options->hideType = FF_GPU_TYPE_UNKNOWN;
+    options->hideType = FF_GPU_TYPE_NONE;
     options->tempConfig = (FFColorRangeConfig) { 60, 80 };
     options->percent = (FFPercentageModuleConfig) { 50, 80, 0 };
 }
