@@ -9,5 +9,5 @@ typedef struct FFWifiOptions
     FFModuleBaseInfo moduleInfo;
     FFModuleArgs moduleArgs;
 
-    FFColorRangeConfig percent;
+    FFPercentageModuleConfig percent;
 } FFWifiOptions;
