@@ -593,6 +593,62 @@ int main(void)
     VERIFY(ffStrbufRemoveDupWhitespaces(&strbuf) == false);
     VERIFY(strcmp(strbuf.chars, "   ") == 0);
 
+    {
+        ffStrbufSetStatic(&strbuf, "abcdef");
+        FF_STRBUF_AUTO_DESTROY newStr = ffStrbufCreateCopy(&strbuf);
+        VERIFY(newStr.allocated == 0);
+        VERIFY(newStr.chars == strbuf.chars);
+    }
+
+    {
+        ffStrbufSetStatic(&strbuf, "abcdef");
+        FF_STRBUF_AUTO_DESTROY newStr = ffStrbufCreateS("123456");
+        ffStrbufSet(&newStr, &strbuf);
+        VERIFY(newStr.allocated > 0);
+        VERIFY(newStr.chars != strbuf.chars);
+        VERIFY(ffStrbufEqualS(&newStr, "abcdef"));
+    }
+
+    {
+        ffStrbufSetStatic(&strbuf, "abcdefghijkl");
+        FF_STRBUF_AUTO_DESTROY newStr = ffStrbufCreateS("123456");
+        ffStrbufSet(&newStr, &strbuf);
+        VERIFY(newStr.allocated > 0);
+        VERIFY(newStr.chars != strbuf.chars);
+        VERIFY(ffStrbufEqualS(&newStr, "abcdefghijkl"));
+    }
+
+    {
+        ffStrbufClear(&strbuf);
+        FF_STRBUF_AUTO_DESTROY newStr = ffStrbufCreateCopy(&strbuf);
+        VERIFY(newStr.allocated == 0);
+        VERIFY(newStr.chars == strbuf.chars);
+        VERIFY(newStr.chars[0] == '\0');
+    }
+
+    {
+        ffStrbufClear(&strbuf);
+        FF_STRBUF_AUTO_DESTROY newStr = ffStrbufCreateS("123456");
+        ffStrbufSet(&newStr, &strbuf);
+        VERIFY(newStr.allocated > 0);
+        VERIFY(newStr.chars != strbuf.chars);
+        VERIFY(ffStrbufEqualS(&newStr, ""));
+    }
+
+    {
+        ffStrbufSetStatic(&strbuf, "abc");
+        VERIFY(ffStrbufMatchSeparatedS(&strbuf, "abc:def:ghi", ' ') == false);
+        VERIFY(ffStrbufMatchSeparatedS(&strbuf, "abc:def:ghi", ':') == true);
+        VERIFY(ffStrbufMatchSeparatedS(&strbuf, "def:ghi", ' ') == false);
+        VERIFY(ffStrbufMatchSeparatedS(&strbuf, "def:ghi", ':') == false);
+        VERIFY(ffStrbufMatchSeparatedS(&strbuf, "def", ':') == false);
+        VERIFY(ffStrbufMatchSeparatedS(&strbuf, "abc", ':') == true);
+        VERIFY(ffStrbufMatchSeparatedS(&strbuf, "", ' ') == false);
+        VERIFY(ffStrbufMatchSeparatedS(&strbuf, ":abc:", ':') == true);
+        VERIFY(ffStrbufMatchSeparatedS(&strbuf, "abc:", ':') == true);
+        VERIFY(ffStrbufMatchSeparatedS(&strbuf, ":abc", ':') == true);
+    }
+
     //Success
     puts("\e[32mAll tests passed!" FASTFETCH_TEXT_MODIFIER_RESET);
 }
